@@ -1,10 +1,10 @@
-import zipfile
 import json
+import zipfile
 
 from .base import importer
 from ..parsers.baseporter import ExtraOption
 from ..parsers.tgs import parse_tgs
-from ..objects import Animation
+from ..objects import Animation, assets
 
 
 @importer("dotLottie Archive", ["lottie"], [
@@ -21,4 +21,12 @@ def import_dotlottie(file, id=None):
         info = zf.getinfo("animations/%s.json" % id)
 
         with zf.open(info) as animfile:
-            return Animation.load(json.load(animfile))
+            an = Animation.load(json.load(animfile))
+            if an.assets:
+                for asset in an.assets:
+                    if isinstance(asset, assets.Image) and not asset.embedded:
+                        fname = asset.image_path + asset.image
+                        if fname in zf.namelist():
+                            with zf.open(fname) as imgfile:
+                                asset.load(imgfile)
+            return an
