@@ -170,20 +170,20 @@ class OffsetKeyframe(Keyframe):
     _props = [
         TgsProp("start", "s", NVector, False),
         TgsProp("end", "e", NVector, False),
-        TgsProp("in_tan", "ti", NVector, True),
-        TgsProp("out_tan", "to", NVector, True),
+        TgsProp("in_tan", "ti", NVector, False),
+        TgsProp("out_tan", "to", NVector, False),
     ]
 
-    def __init__(self, time=0, start=None, end=None, easing_function=None):
+    def __init__(self, time=0, start=None, end=None, easing_function=None, in_tan=None, out_tan=None):
         Keyframe.__init__(self, time, easing_function)
         ## Start value of keyframe segment.
         self.start = start
         ## End value of keyframe segment.
         self.end = end
         ## In Spatial Tangent. Only for spatial properties. (for bezier smoothing on position)
-        self.in_tan = None
+        self.in_tan = in_tan
         ## Out Spatial Tangent. Only for spatial properties. (for bezier smoothing on position)
-        self.out_tan = None
+        self.out_tan = out_tan
 
     def interpolated_value(self, ratio, next_start=None):
         end = next_start if self.end is None else self.end
@@ -195,9 +195,25 @@ class OffsetKeyframe(Keyframe):
             return end
         if ratio == 0:
             return self.start
+        if self.in_tan and self.out_tan:
+            bezier = Bezier()
+            bezier.add_point(self.start, NVector(0, 0), self.out_tan)
+            bezier.add_point(end, self.in_tan, NVector(0, 0))
+            return bezier.point_at(ratio)
+
         lerpv = self.lerp_factor(ratio)
         return self.start.lerp(end, lerpv)
 
+    def interpolated_tangent_angle(self, ratio, next_start=None):
+        end = next_start if self.end is None else self.end
+        if end is None or not self.in_tan or not self.out_tan:
+            return 0
+
+        bezier = Bezier()
+        bezier.add_point(self.start, NVector(0, 0), self.out_tan)
+        bezier.add_point(end, self.in_tan, NVector(0, 0))
+        return bezier.tangent_angle_at(ratio)
+
     def __repr__(self):
         return "<%s.%s %s %s%s>" % (
             type(self).__module__,
@@ -229,11 +245,13 @@ class AnimatableMixin:
         self.animated = False
         self.keyframes = None
 
-    def add_keyframe(self, time, value, interp=easing.Linear()):
+    def add_keyframe(self, time, value, interp=easing.Linear(), *args, **kwargs):
         """!
-        \param time     The time this keyframe appears in
-        \param value    The value the property should have at \p time
-        \param interp   The easing callable used to update the tangents of the previous keyframe
+        @param time     The time this keyframe appears in
+        @param value    The value the property should have at \p time
+        @param interp   The easing callable used to update the tangents of the previous keyframe
+        @param args     Extra arguments to pass the keyframe constructor
+        @param kwargs   Extra arguments to pass the keyframe constructor
         @note Always call add_keyframe with increasing \p time value
         """
         if not self.animated:
@@ -252,7 +270,9 @@ class AnimatableMixin:
             time,
             value,
             None,
-            interp
+            interp,
+            *args,
+            **kwargs
         ))
 
     def get_value(self, time=0):
@@ -265,6 +285,9 @@ class AnimatableMixin:
         if not self.keyframes:
             return None
 
+        return self._get_value_helper(time)[0]
+
+    def _get_value_helper(self, time):
         val = self.keyframes[0].start
         for i in range(len(self.keyframes)):
             k = self.keyframes[i]
@@ -274,15 +297,18 @@ class AnimatableMixin:
 
                 kp = self.keyframes[i-1] if i > 0 else None
                 if kp:
+                    t = (time - kp.time) / (k.time - kp.time)
                     end = kp.end
                     if end is None:
                         end = val
                     if end is not None:
-                        val = kp.interpolated_value((time - kp.time) / (k.time - kp.time), end)
-                break
+                        val = kp.interpolated_value(t, end)
+                    return val, end, kp, t
+                return val, None, None, None
             if k.end is not None:
                 val = k.end
-        return val
+        return val, None, None, None
+
 
     def to_dict(self):
         d = super().to_dict()
@@ -313,6 +339,23 @@ class MultiDimensional(AnimatableMixin, TgsObject):
         TgsProp("keyframes", "k", OffsetKeyframe, True, lambda l: l.get("a", None)),
     ]
 
+    def get_tangent_angle(self, time=0):
+        """!
+        @brief Returns the value tangent angle of the property at the given frame/time
+        """
+        if not self.keyframes or len(self.keyframes) < 2:
+            return 0
+
+        val, end, kp, t = self._get_value_helper(time)
+        if kp:
+            return kp.interpolated_tangent_angle(t, end)
+
+        if self.keyframes[0].time >= time:
+            end = self.keyframes[0].end if self.keyframes[0].end is not None else self.keyframes[1].start
+            return self.keyframes[0].interpolated_tangent_angle(0, end)
+
+        return 0
+
 
 ## \ingroup Lottie
 class GradientColors(TgsObject):
