@@ -337,12 +337,12 @@ class Ellipse(Shape):
     ## %Shape type.
     type = "el"
 
-    def __init__(self):
+    def __init__(self, position=None, size=None):
         Shape.__init__(self)
         ## Ellipse's position
-        self.position = MultiDimensional(NVector(0, 0))
+        self.position = MultiDimensional(position or NVector(0, 0))
         ## Ellipse's size
-        self.size = MultiDimensional(NVector(0, 0))
+        self.size = MultiDimensional(size or NVector(0, 0))
 
     def bounding_box(self, time=0):
         pos = self.position.get_value(time)
@@ -560,7 +560,7 @@ class GradientFill(ShapeElement, Gradient):
     """
     _props = [
         TgsProp("opacity", "o", Value, False),
-        TgsProp("r", "r", int, False),
+        TgsProp("fill_rule", "r", FillRule, False),
     ]
     ## %Shape type.
     type = "gf"
@@ -570,8 +570,8 @@ class GradientFill(ShapeElement, Gradient):
         Gradient.__init__(self, colors)
         ## Fill Opacity
         self.opacity = Value(100)
-        ## \todo figure out?
-        self.r = None
+        ## Fill rule
+        self.fill_rule = None
 
 
 ## \ingroup Lottie
